Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CombinedFilter ¶
type CombinedFilter struct {
// contains filtered or unexported fields
}
CombinedFilter matches if ANY of its sub-filters match (OR logic).
func (*CombinedFilter) Match ¶
func (f *CombinedFilter) Match(s string) bool
type Filter ¶
func Compile ¶
Compile takes a list of string filters and returns a Filter interface for matching a given string against the filter list (OR logic).
Patterns surrounded by / are treated as regular expressions:
f, _ := Compile([]string{"*error*", "/(?i)panic|segfault/"})
f.Match("an error occurred") // true (glob match)
f.Match("KERNEL PANIC") // true (regex match)
f.Match("normal log") // false
Plain patterns support glob matching:
f, _ := Compile([]string{"cpu", "mem", "net*"})
f.Match("cpu") // true
f.Match("network") // true
f.Match("memory") // false
func NewIncludeExcludeFilter ¶
type IncludeExcludeFilter ¶
type IncludeExcludeFilter struct {
// contains filtered or unexported fields
}
func (*IncludeExcludeFilter) Match ¶
func (f *IncludeExcludeFilter) Match(s string) bool
Click to show internal directories.
Click to hide internal directories.